@@ -3,7 +3,7 @@ package Debian::AptContents;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 =head1 NAME
 
@@ -11,7 +11,7 @@ Debian::AptContents - parse/search through apt-file's Contents files
 
 =head1 SYNOPSIS
 
-    my $c = Debian::AptContents->new( { cache_dir => '~/.cache/dh-make-perl' } );
+    my $c = Debian::AptContents->new( { homedir => '~/.dh-make-perl' } );
     my @pkgs = $c->find_file_packages('/usr/bin/foo');
     my $dep = $c->find_perl_module_package('Foo::Bar');
 
@@ -27,16 +27,15 @@ subclass Debian::AptContents, which needs to become more generic.
 use base qw(Class::Accessor);
 __PACKAGE__->mk_accessors(
     qw(
-        homedir cache cache_dir cache_file contents_files verbose
+        cache homedir cache_file contents_files verbose
         source dist
         )
 );
 
 use Config;
 use Debian::Dependency;
-use DhMakePerl::Utils qw(find_core_perl_dependency is_core_perl_package);
+use DhMakePerl::Utils qw(find_core_perl_dependency);
 use File::Spec::Functions qw( catfile catdir splitpath );
-use File::Path qw(make_path);
 use IO::Uncompress::Gunzip;
 use List::MoreUtils qw(uniq);
 use Module::CoreList ();
@@ -53,7 +52,7 @@ our $oldstable_perl = '5.14.2';
 
 =item new
 
-Constructs new instance of the class. Expects at least C<cache_dir> option.
+Constructs new instance of the class. Expects at least C<homedir> option.
 
 =back
 
@@ -61,13 +60,9 @@ Constructs new instance of the class. Expects at least C<cache_dir> option.
 
 =over
 
-=item cache_dir
-
-(B<mandatory>) Directory where the object stores its cache.
-
 =item homedir
 
-Legacy option to specify the cache directory.
+(B<mandatory>) Directory where the object stores its cache.
 
 =item dist
 
@@ -81,7 +76,7 @@ Arrayref of F<Contents> file names. Default is to let B<apt-file> find them.
 =item cache_file
 
 Path to the file with cached parsed information from all F<Contents> files.
-Default is F<Contents.cache> under C<cache_dir>.
+Default is F<Contents.cache> under C<homedir>.
 
 =item cache
 
@@ -101,18 +96,14 @@ sub new {
     $class = ref($class) if ref($class);
     my $self = $class->SUPER::new(@_);
 
-    # backwards compatibility
-    $self->cache_dir( $self->homedir )
-        if $self->homedir and not $self->cache_dir;
-
     # required options
-    $self->cache_dir
-        or die "No cache_dir given";
+    $self->homedir
+        or die "No homedir given";
 
     # some defaults
     $self->contents_files( $self->get_contents_files )
         unless $self->contents_files;
-    $self->cache_file( catfile( $self->cache_dir, 'Contents.cache' ) )
+    $self->cache_file( catfile( $self->homedir, 'Contents.cache' ) )
         unless $self->cache_file;
     $self->verbose(1) unless defined( $self->verbose );
 
@@ -166,7 +157,7 @@ sub get_contents_files {
         chomp($line);
         next unless $line =~ m/^Contents-deb/;
         my ( $index_name, $arch, $suite, $filename ) = split( ' ', $line, 4 );
-        next unless $arch eq $archspec or $arch eq 'all';
+        next unless $arch eq $archspec;
         if ( $self->dist ) {
             next unless $suite eq $self->dist;
         }
@@ -186,48 +177,6 @@ invocation.
 
 =cut
 
-# distribute files so that the load (measured by file size) is distributed
-# more or less equally
-sub _distribute_files {
-    my ( $self, $files, $cpus ) = @_;
-
-    $cpus = scalar(@$files) if scalar(@$files) < $cpus;
-
-    return $files unless $cpus > 1;
-
-    my @data = map( { file => $_, size => -s $_ }, @$files );
-    @data = sort { $b->{size} <=> $a->{size} } @data;
-
-    my ( @slots, @slot_load );
-    for(1..$cpus) {
-        push @slots, [];
-        push @slot_load, 0;
-    }
-
-    for my $item (@data) {
-        my $lightest_slot = 0;
-        my $lightest_slot_load = $slot_load[0];
-        for my $slot ( 1 .. $#slots ) {
-            next unless $slot_load[$slot] < $lightest_slot_load;
-
-            $lightest_slot      = $slot;
-            $lightest_slot_load = $slot_load[$slot];
-        }
-
-        push @{ $slots[$lightest_slot] }, $item->{file};
-        $slot_load[$lightest_slot] += $item->{size};
-    }
-
-    if (0) {
-        for my $slot (@slots) {
-            warn "Slot package: \n";
-            warn sprintf( "  %8d=%s\n", -s $_, $_ ) for @$slot;
-        }
-    }
-
-    return @slots;
-}
-
 sub read_cache {
     my $self = shift;
 
@@ -268,134 +217,36 @@ sub read_cache {
             $cache->{apt_contents}   = {};
 
             push @{ $cache->{contents_files} }, @{ $self->contents_files };
+            my @cat_cmd = (
+                '/usr/lib/apt/apt-helper', 'cat-file', @{ $self->contents_files }
+            );
+            open( my $f, "-|", @cat_cmd )
+                or die
+                "Can't run '/usr/lib/apt/apt-helper cat-file' on Contents files: $!\n";
 
-            {
-                my $prefix;
-                for my $f ( @{ $self->contents_files } ) {
-                    if ( defined($prefix) ) {
-                        chop($prefix)
-                            while length($prefix)
-                            and not $f =~ /^\Q$prefix\E/;
-                    }
-                    else {
-                        $prefix = $f;
-                    }
-                }
-                $self->warning(
-                    1,
-                    "Parsing Contents files:\n\t"
-                        . join( "\n\t",
-                        map { my $x = $_; $x =~ s{^\Q$prefix\E}{}; $x }
-                            @{ $self->contents_files } )
-                );
-            }
-
-            require IO::Pipe; require IO::Select;
-            my $cpus = eval { require Sys::CPU; Sys::CPU::cpu_count() };
-            unless ($cpus) {
-                $self->warning( 1, "Sys::CPU not available");
-                $self->warning( 1, "Using single parser process");
-                $cpus = 1;
-            }
-
-            # parsing of Contents files goes to forked children. contents_files
-            # is sorted by size, so that no child can have only long Contents.
-            # the number of children is capped to the number of CPUs on the system
-            my ( @kids, %kid_by_fh );
-            for my $portion (
-                $self->_distribute_files( $self->contents_files, $cpus ) )
-            {
-                push @kids, { files => $portion, lines => 0 };
-            }
-
-            my $sel = IO::Select->new;
-
-            # start the children
-            for my $kid (@kids) {
-                my $pipe = IO::Pipe->new;
-                if ( my $pid = fork() ) {    # parent
-                    $pipe->reader;
-
-                    $kid_by_fh{ $pipe->fileno } = $kid;
-                    $kid->{io}                  = $pipe;
-                    $kid->{pid}                 = $pid;
-                    $sel->add( $pipe->fileno );
-                }
-                elsif ( defined($pid) ) {    # child
-                    $pipe->writer;
-                    my @cat_cmd = (
-                        '/usr/lib/apt/apt-helper', 'cat-file',
-                        @{ $kid->{files} }
-                    );
-
-                    open( my $f, "-|", @cat_cmd )
-                        or die sprintf( "Error running '%s': %d\n",
-                        join( ' ', @cat_cmd ), $! );
-
-                    my $line;
-                    while ( defined( $line = $f->getline ) ) {
-                        my ( $file, $packages ) = split( /\s+/, $line );
-                        next unless $file =~ s{
-                            ^usr/
-                            (?:share|lib)/
-                            (?:perl\d+/            # perl5/
-                            | perl/(?:\d[\d.]+)/   # or perl/5.10/
-                            | \S+-\S+-\S+/perl\d+/(?:\d[\d.]+)/  # x86_64-linux-gnu/perl5/5.22/
-                            )
-                        }{}x;
-                        $pipe->print("$file\t$packages\n");
-                    }
-                    close($f);
-                    close($pipe);
-                    exit(0);
-                }
-                else {
-                    die "fork(): $!";
-                }
-            }
-
-            # read children's output
-            while ( $sel->count
-                and my @ready = IO::Select->select( $sel, undef, $sel ) )
-            {
-                my ( $to_read, undef, $errs ) = @ready;
-
-                for my $fh (@$to_read) {
-                    my $kid = $kid_by_fh{$fh};
-                    my $io = $kid->{io}; my $file = $kid->{file};
-                    if ( defined( my $line = <$io> ) ) {
-                        chomp($line);
-                        $kid->{lines}++;
-                        my ( $file, $packages ) = split( '\t', $line );
-                        $cache->{apt_contents}{$file} =
-                            exists $cache->{apt_contents}{$file}
-                            ? $cache->{apt_contents}{$file} . ',' . $packages
-                            : $packages;
-
-                        # $packages is a comma-separated list of
-                        # section/package items. We'll parse it when a file
-                        # matches. Otherwise we'd parse thousands of entries,
-                        # while checking only a couple
-                    }
-                    else {
-                        warn sprintf( "child %d (%s) EOF after %d lines\n",
-                            $kid->{pid}, $kid->{file}, $kid->{lines} )
-                            if 0;
-                        $sel->remove($fh);
-                        close( $kid->{io} );
-                        waitpid( $kid->{pid}, 0 );
-                    }
-                }
-
-                for my $fh (@$errs) {
-                    my $kid = $kid_by_fh{$fh};
-                    $sel->remove($fh);
-                    close( $kid->{io} );
-                    waitpid( $kid->{pid}, 0 );
-                    die sprintf( "child %d (%s) returned %d\n",
-                        $kid->{pid}, join( ', ', @{ $kid->{files} } ), $? );
-                }
+            $self->warning( 1,
+                "Parsing Contents files:\n\t"
+                    . join( "\n\t", @{ $self->contents_files } ) );
+            my $line;
+            while ( defined( $line = $f->getline ) ) {
+                my ( $file, $packages ) = split( /\s+/, $line );
+                next unless $file =~ s{
+                    ^usr/
+                    (?:share|lib)/
+                    (?:perl\d+/            # perl5/
+                    | perl/(?:\d[\d.]+)/   # or perl/5.10/
+                    )
+                }{}x;
+                $cache->{apt_contents}{$file} = exists $cache->{apt_contents}{$file}
+                    ? $cache->{apt_contents}{$file}.','.$packages
+                    : $packages;
+
+                # $packages is a comma-separated list of
+                # section/package items. We'll parse it when a file
+                # matches. Otherwise we'd parse thousands of entries,
+                # while checking only a couple
             }
+            close($f);
 
             if ( %{ $cache->{apt_contents} } ) {
                 $self->cache($cache);
@@ -428,7 +279,7 @@ sub store_cache {
 
     $dir = catdir( $vol, $dir );
     unless ( -d $dir ) {
-        make_path( $dir )
+        mkdir $dir
             or die "Error creating directory '$dir': $!\n";
     }
 
@@ -463,7 +314,11 @@ sub find_file_packages {
                                                # usr/share/perl5/Config/Any.pm  universe/perl/libconfig-any-perl
 
     # in-core dependencies are given by find_core_perl_dependency
-    @packages = grep { !is_core_perl_package($_) } @packages;
+    @packages = grep {
+        ( $_         ne 'perl-base' )
+            and ( $_ ne 'perl' )
+            and ( $_ ne 'perl-modules' )
+    } @packages;
 
     return uniq @packages;
 }
@@ -471,11 +326,15 @@ sub find_file_packages {
 =item find_perl_module_package( $module, $version )
 
 Given Perl module name (e.g. Foo::Bar), returns a L<Debian::Dependency> object
-representing the required Debian package and version. If the module is only in perl core,
-a suitable dependency on perl is returned.
+representing the required Debian package and version. If the module is a core
+one, suitable dependency on perl is returned.
 
-For dual-lived modules, which are in perl and in a separate package, only
-the latter is returned, as the perl package has versioned Provides for them.
+If the package is also available in a separate package, an alternative
+dependency is returned.
+
+In case the version of the currently running Perl interpreter is lower than the
+version in which the wanted module is available in core, the separate package
+is preferred. Otherwise the perl dependency is the first alternative.
 
 =cut
 
@@ -498,8 +357,8 @@ sub find_perl_module_package {
         else                     { return $a cmp $b; }    # or 0?
     } @matches;
 
-    # we don't want perl packages here
-    @matches = grep { !is_core_perl_package($_) } @matches;
+    # we don't want perl, perl-base and perl-modules here
+    @matches = grep { !/^perl(?:-(?:base|modules))?$/ } @matches;
 
     my $direct_dep;
     $direct_dep = Debian::Dependency->new(
@@ -508,10 +367,27 @@ sub find_perl_module_package {
         : ( $matches[0], $version )
     ) if @matches;
 
+    my $running_perl = $Config::Config{version};
+
     if ($core_dep) {
+
+        # the core dependency is satosfied by oldstable?
+        if ( $core_dep->ver <= $oldstable_perl ) {
+            # drop the direct dependency and remove the version
+            undef($direct_dep);
+
+            $core_dep->ver(undef);
+            $core_dep->rel(undef);
+        }
+
         if ($direct_dep) {
             # both in core and in a package.
-            return $direct_dep;
+            if( $running_perl >= $core_dep->ver ) {
+                return Debian::Dependency->new("$core_dep | $direct_dep");
+            }
+            else {
+                return Debian::Dependency->new("$direct_dep | $core_dep");
+            }
         }
         else {
             # only in core
@@ -542,9 +418,9 @@ sub find_perl_module_package {
 
 =over 4
 
-=item Copyright (C) 2008, 2009, 2010, 2017 Damyan Ivanov <dmn@debian.org>
+=item Copyright (C) 2008, 2009, 2010 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2016, 2019 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2016, gregor herrmann <gregoa@debian.org>
 
 =back
 
