@@ -16,24 +16,19 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 use Carp qw(croak);
 
 use base 'Debian::Control';
 
 use CPAN ();
-use DhMakePerl::Utils qw( is_core_module find_cpan_module nice_perl_ver
-  split_version_relation apt_cache is_core_perl_package );
+use DhMakePerl::Utils qw( is_core_module find_cpan_module nice_perl_ver split_version_relation apt_cache );
 use File::Spec qw( catfile );
 use Module::Depends ();
 
 use constant oldstable_perl_version => '5.14.2';
 
-# Temporarily disable the warning until dpkg 1.20.x, as our usage is correct.
-no if $Dpkg::Version::VERSION ge '1.02',
-   warnings => qw(Dpkg::Version::semantic_change::overload::bool);
-
 =head1 METHODS
 
 =over
@@ -53,12 +48,11 @@ An instance of L<Debian::AptContents> to be used when locating to which package
 a required module belongs.
 
 =item dpkg_available
-
-An instance of L<Dpkg::Index> to be used when checking whether
+An instance of L<DPKG::Parse::Available> to be used when checking whether
 the locally available package is the required version. For example:
 
-    my $available = Dpkg::Index->new(type => CTRL_INFO_PKG);
-    $available->load("$Dpkg::ADMINDIR/available");
+    my $available = DPKG::Parse::Available->new;
+    $available->parse;
 
 =item dir
 
@@ -116,7 +110,6 @@ sub discover_dependencies {
     my $install_deps = delete $opts->{install_deps};
     my $install_build_deps = delete $opts->{install_build_deps};
     my $wnpp_query = delete $opts->{wnpp_query};
-    my $guess_nocheck = delete $opts->{guess_nocheck};
 
     die "Unsupported option(s) given: " . join( ', ', sort( keys(%$opts) ) )
         if %$opts;
@@ -172,7 +165,7 @@ sub discover_dependencies {
                         . "Automatic find of" 
                         . " dependencies failed. You may want to \n"
                         . "retry using the '--[b]depends[i]' options\n"
-                        . "or just fill the dependency fields in debian/control"
+                        . "or just fill the dependency fields in debian/rules"
                         . " by hand\n";
 
                         return;
@@ -200,22 +193,12 @@ sub discover_dependencies {
                 . join( ", ", @$debs ) . "\n";
         }
         $bin->Depends->add(@$debs);
-
-        # add runtime dependencies to Build-Depends{,-Indep} as well,
-        # as they are most likely needed for tests, but mark
-        # them as '!<nocheck>' like the test dependencies
-        my $r_debs = Debian::Dependencies->new($debs);
-        foreach (@$r_debs) {
-            $_->{profile} = '!nocheck' unless is_core_perl_package($_->{pkg});
-        }
-
         if ( $bin->Architecture eq 'all' ) {
-            $src->Build_Depends_Indep->add(@$r_debs);
+            $src->Build_Depends_Indep->add(@$debs);
         }
         else {
-            $src->Build_Depends->add(@$r_debs);
+            $src->Build_Depends->add(@$debs);
         }
-
         if ($install_deps) {
             foreach my $deb (@$debs) {
                 _install_deb($deb->pkg) unless grep {$deb} @$missing;
@@ -226,86 +209,33 @@ sub discover_dependencies {
     # build-time
     my ( $b_debs, $b_missing ) = $self->find_debs_for_modules(
         {   %{ $deps->{build_requires}     || {} },
+            %{ $deps->{test_requires}      || {} },
             %{ $deps->{configure_requires} || {} }
         },
         $apt_contents,
         $verbose,
         $dpkg_available,
     );
-    push @$missing, @$b_missing;
 
-    # still build-time but test_requires only
-    my ( $t_debs, $t_missing ) = $self->find_debs_for_modules(
-        {   %{ $deps->{test_requires} || {} }
-        },
-        $apt_contents,
-        $verbose,
-        $dpkg_available,
-    );
-    push @$missing, @$t_missing;
-
-    # add <!nocheck> profile to test dependencies
-    foreach (@$t_debs) {
-        $_->{profile} = '!nocheck' unless is_core_perl_package($_->{pkg});
-    }
-
-    # add <!nocheck> when there are no declared test dependencies
-    # to new as well as existing (on refresh)
-    # build dependencies that are likely to be used only for testing
-    # if Debian::PkgPerl::Util is not available, or the --guess-nocheck option
-    # is not specified, limit only to libtest-*
-    unless (@$t_debs) {
-        if ($guess_nocheck and eval { require Debian::PkgPerl::Util }) {
-            foreach (
-                @$b_debs,
-                @{$src->Build_Depends},
-                @{$src->Build_Depends_Indep}
-                )
-            {
-                $_->{profile} = '!nocheck'
-                    unless Debian::PkgPerl::Util->probable_build_dependency(
-                        $_->{pkg});
-            }
-        }
-        else {
-            foreach (
-                @$b_debs,
-                @{$src->Build_Depends},
-                @{$src->Build_Depends_Indep}
-                )
-            {
-                $_->{profile} = '!nocheck' if $_->{pkg} =~ /^libtest-/;
-            }
-        }
-    }
-
-    if (@$b_debs || @$t_debs) {
+    if (@$b_debs) {
         if ($verbose) {
             print "\n";
-            print "Needs the following debian packages during building and testing: "
-                . join( ", ", @$b_debs, @$t_debs ) . "\n";
+            print "Needs the following debian packages during building: "
+                . join( ", ", @$b_debs ) . "\n";
         }
         if ( $self->is_arch_dep ) {
             $src->Build_Depends->add(@$b_debs);
-            $src->Build_Depends->add(@$t_debs);
         }
         else {
             $src->Build_Depends_Indep->add(@$b_debs);
-            $src->Build_Depends_Indep->add(@$t_debs);
         }
-        if ( $install_build_deps || $install_deps ) {
-            _install_deb( $_->pkg ) foreach ( @$b_debs, @$t_debs );
+        if ($install_build_deps || $install_deps) {
+            _install_deb($_->pkg)
+                foreach @$b_debs;
         }
     }
 
-    # s/perl/perl:native/ in Build-Depends
-    if ( $self->is_arch_dep ) {
-        my ($perl) = $src->Build_Depends->remove('perl');
-        if ($perl) {
-            $perl->{pkg} = 'perl:native';
-            $src->Build_Depends->add($perl);
-        }
-    }
+    push @$missing, @$b_missing;
 
     if (@$missing) {
         my ($missing_debs_str);
@@ -361,9 +291,9 @@ Scans the given hash of dependencies ( module => version ) and returns
 matching Debian package dependency specification (as an instance of
 L<Debian::Dependencies> class) and a list of missing modules.
 
-Installed packages and perl core are searched first, then the APT contents.
+Perl core is searched first, then installed packages, then the APT contents.
 
-If a Dpkg::Index object is passed, also check the available package version.
+If a DPKG::Parse::Available object is passed, also check the available package version
 
 =cut
 
@@ -384,86 +314,122 @@ sub find_debs_for_modules {
 
         $version =~ s/^v// if $version;
 
-        my ( $dep, $core_dep, $direct_dep );
+        my $dep;
 
+        require Debian::DpkgLists;
         if ( my $ver = is_core_module( $module, $version ) ) {
-            $core_dep = Debian::Dependency->new( 'perl', $ver );
+            $dep = Debian::Dependency->new( 'perl', $ver );
         }
-        if (!$direct_dep && $apt_contents) {
-            $direct_dep = $apt_contents->find_perl_module_package( $module, $version );
+        elsif ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
+            $dep = Debian::Dependency->new(
+                  ( @pkgs > 1 )
+                ? [ map { { pkg => $_, ver => $version } } @pkgs ]
+                : ( $pkgs[0], $version )
+            );
+
+            # Check the actual version available, if we've been passed
+            # a DPKG::Parse::Available object
+            if ( $dpkg_available ) {
+                my @available;
+                my @satisfied = grep {
+                    if ( my $pkg = $dpkg_available->get_package('name' => $_) ) {
+                        my $have_pkg = Debian::Dependency->new( $_, '=', $pkg->version );
+                        push @available, $have_pkg;
+                        $have_pkg->satisfies($dep);
+                    }
+                    else {
+                        warn qq(Unable to obtain version information for $module. You may need to )
+                            .qq(install and run "dselect update");
+                    }
+                } @pkgs;
+                unless ( @satisfied ) {
+                    print "$module is available locally as @available, but does not satisfy $version"
+                        if $verbose;
+                    push @missing, $module;
+                }
+            }
+            else {
+                warn "DPKG::Parse not available. Not checking version of $module.";
+            }
+        }
+
+        if (!$dep && $apt_contents) {
+            $dep = $apt_contents->find_perl_module_package( $module, $version );
 
             # Check the actual version in APT, if we've got
             # a AptPkg::Cache object to search
-            if ( $direct_dep && $aptpkg_cache ) {
-                my $pkg = $aptpkg_cache->{$direct_dep->pkg};
+            if ( $dep && $aptpkg_cache ) {
+                my $pkg = $aptpkg_cache->{$dep->pkg};
                 if ( my $available = $pkg->{VersionList} ) {
-                    my $found = 0;
                     for my $v ( @$available ) {
-                        my $d = Debian::Dependency->new( $direct_dep->pkg, '=', $v->{VerStr} );
-
-                        next unless $d->satisfies($direct_dep);
-
-                        $found = 1;
-                        last;
-                    }
-
-                    unless ($found) {
+                        my $d = Debian::Dependency->new( $dep->pkg, '=', $v->{VerStr} );
+                        last if $d->satisfies($dep); # exit loop if we have a good version; otherwise:
                         push @missing, $module;
-                        print "$module packages in APT do not satisfy $direct_dep"
+                        print "$module package in APT ($d) does not satisfy $dep"
                             if $verbose;
                     }
                 }
             }
         }
 
-        if (!$direct_dep) {
-            require Debian::DpkgLists;
-            if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
-                # core packages should be included above
-                # it is normal to have them here, in case the version
-                # requirement can't be satisfied by the current perl
-                @pkgs = grep { !is_core_perl_package($_) } @pkgs;
 
-                if (@pkgs) {
-                    $direct_dep = Debian::Dependency->new(
-                          ( @pkgs > 1 )
-                        ? [ map { { pkg => $_, ver => $version } } @pkgs ]
-                        : ( $pkgs[0], $version )
-                    );
-
-                    # Check the actual version available, if we've been passed
-                    # a Dpkg::Index object
-                    # (evaluates as "$thing" in boolean context;
-                    # takes 6.5 seconds)
-                    if ( defined $dpkg_available ) {
-                        my @available;
-                        my @satisfied = grep {
-                            if ( my $pkg = $dpkg_available->get_by_key($_) ) {
-                                my $have_pkg = Debian::Dependency->new( $_, '=', $pkg->{Version} );
-                                push @available, $have_pkg;
-                                $have_pkg->satisfies($direct_dep);
-                            }
-                            else {
-                                warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
-                                    .qq(You may need to run "apt-cache dumpavail | dpkg --merge-avail");
-                            }
-                        } @pkgs;
-                        unless ( @satisfied ) {
-                            print "$module is available locally as @available, but does not satisfy $version\n"
-                                if $verbose;
-                            push @missing, $module;
-                        }
-                    }
-                }
-            }
-        }
-
-        $dep = $direct_dep || $core_dep;
         $dep->rel($ver_rel) if $dep and $ver_rel and $dep->ver;
 
         my $mod_ver = join( " ", $module, $ver_rel // (), $version || () );
         if ($dep) {
-            print "+ $mod_ver found in $dep\n" if $verbose
+            if ($verbose) {
+                if ( $dep->pkg and $dep->pkg eq 'perl' ) {
+                    print "= $mod_ver is in core";
+                    print " since " . $dep->ver if $dep->ver;
+                    print "\n";
+                }
+                else {
+                    print "+ $mod_ver found in $dep\n";
+                }
+            }
+
+            my $target_perl_version = $^V;
+            $target_perl_version =~ s/^v//;
+            $target_perl_version = Dpkg::Version->new($target_perl_version);
+
+            if (    $dep->pkg
+                and $dep->pkg eq 'perl'
+                and $dep->ver
+                and $dep->ver > $target_perl_version )
+            {
+                print "  ! $dep is too new. Adding alternative dependency\n"
+                    if $verbose;
+
+                my $alt_dep;
+
+                if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
+                    @pkgs = grep {
+                                ( $_ ne 'perl-modules' )
+                            and ( $_ ne 'perl-base' )
+                            and ( $_ ne 'perl' )
+                    } @pkgs;
+
+                    $alt_dep = Debian::Dependency->new(
+                          ( @pkgs > 1 )
+                        ? [ map { { pkg => $_, ver => $version } } @pkgs ]
+                        : ( $pkgs[0], $version )
+                    ) if @pkgs;
+                }
+
+                if ( not $alt_dep and $apt_contents) {
+                    $alt_dep
+                        = $apt_contents->find_perl_module_package( $module,
+                        $version );
+                }
+
+                $alt_dep
+                    //= Debian::Dependency->new(
+                    $self->module_name_to_pkg_name($module),
+                    '>=', $version );
+
+                $dep = Debian::Dependency->new("$alt_dep | $dep");
+                #print "    $dep\n";
+            }
         }
         else {
             print "- $mod_ver not found in any package\n";
@@ -511,7 +477,7 @@ The following checks are made
 
 =over
 
-=item dependencies on C<perl-modules*> and C<libperl*>
+=item dependencies on C<perl-modules>
 
 These are replaced with C<perl> as per Perl policy.
 
@@ -533,7 +499,7 @@ if the dependency is redundant.
 
 =item pruned dependency
 
-otherwise. C<perl-modules*> and C<libperl*> replaced with C<perl>.
+otherwise. C<perl-modules> replaced with C<perl>.
 
 =back
 
@@ -545,11 +511,10 @@ sub prune_simple_perl_dep {
     croak "No alternative dependencies can be given"
         if $dep->alternatives;
 
-    return $dep unless is_core_perl_package( $dep->pkg );
+    return $dep unless $dep->pkg =~ /^(?:perl|perl-base|perl-modules)$/;
 
     # perl-modules is replaced with perl
-    $dep->pkg('perl')
-      if $dep->pkg =~ /^(?:perl-modules(?:-[\d.]+)?|libperl[\d.]+)$/;
+    $dep->pkg('perl') if $dep->pkg eq 'perl-modules';
 
     my $unversioned = (
         not $dep->ver
@@ -569,7 +534,7 @@ sub prune_simple_perl_dep {
         if $dep->pkg eq 'perl-base' and $unversioned;
 
     # perl is needed in build-dependencies (see Policy 4.2)
-    return $dep if $dep->pkg =~ '^perl(:native)?$' and $build;
+    return $dep if $dep->pkg eq 'perl' and $build;
 
     # unversioned perl non-build-dependency is redundant, because it will be
     # covered by ${perl:Depends}
@@ -609,8 +574,7 @@ sub prune_perl_dep {
 
 =item prune_perl_deps
 
-Remove redundant (build-)dependencies on perl, libperl, perl-modules and
-perl-base.
+Remove redundant (build-)dependencies on perl, perl-modules and perl-base.
 
 =cut
 
@@ -618,7 +582,7 @@ sub prune_perl_deps {
     my $self = shift;
 
     # remove build-depending on ancient perl versions
-    for my $perl ( qw( perl perl-base perl-modules perl:native ) ) {
+    for my $perl ( qw( perl perl-base perl-modules ) ) {
         for ( qw( Build_Depends Build_Depends_Indep ) ) {
             my @ess = $self->source->$_->remove($perl);
             # put back non-redundant ones (possibly modified)
@@ -631,7 +595,7 @@ sub prune_perl_deps {
     }
 
     # remove depending on ancient perl versions
-    for my $perl ( qw( perl perl-base perl-modules perl:native ) ) {
+    for my $perl ( qw( perl perl-base perl-modules ) ) {
         for my $pkg ( $self->binary_tie->Values ) {
             for my $rel ( qw(Depends Recommends Suggests) ) {
                 my @ess = $pkg->$rel->remove($perl);
@@ -680,8 +644,6 @@ sub module_name_to_pkg_name {
 
 Copyright (C) 2009, 2010, 2012 Damyan Ivanov L<dmn@debian.org>
 
-Copyright (C) 2019, 2020 gregor herrmann L<gregoa@debian.org>
-
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
 Software Foundation.
