@@ -12,7 +12,7 @@ Debian::Control::Stanza - single stanza of Debian source package control file
 
 =head1 DESCRIPTION
 
-Debian::Control::Stanza is the base class for
+Debian::Control::Stanza ins the base class for
 L<Debian::Control::Stanza::Source> and L<Debian::Control::Stanza::Binary>
 classes.
 
@@ -25,14 +25,13 @@ require v5.10.0;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 use base qw( Class::Accessor Tie::IxHash );
 
 use Carp qw(croak);
 use Debian::Control::Stanza::CommaSeparated;
 use Debian::Dependencies;
-use Sub::Install;
 
 =head1 FIELDS
 
@@ -45,15 +44,6 @@ Fields that are to contain dependency lists (as per L</is_dependency_list>
 method below) are automatically converted to instances of the
 L<Debian::Dependencies> class.
 
-=head2 User-defined fields
-
-User-defined fields are supported. These start with C<X>, optionally followed
-by C<S>, C<B> or C<C>, then C<_>, capital letter and other letters and digits.
-
-Examples: C<X_Moon_Phase>, C<XS_Hemisphere>.
-
-See L<https://www.debian.org/doc/debian-policy/#user-defined-fields>.
-
 =cut
 
 use constant fields => ();
@@ -91,22 +81,13 @@ sub new {
     my $class = shift;
     my $init = shift || {};
 
-    # map the accessor name for the lower case equivalent
-    my %canonical = map (
-        ( lc($_) => $_ ),
-        $class->fields,
-    );
-
     my $self = Tie::IxHash->new;
 
     bless $self, $class;
 
     while( my($k,$v) = each %$init ) {
         $k =~ s/-/_/g;
-        # translate field name into the accessor canonical name
-        $k = $canonical{ lc $k } || $k;
         $self->can($k)
-            or $self->looks_like_an_x_field($k)
             or croak "Invalid field given ($k)";
         $self->$k($v);
     }
@@ -126,40 +107,6 @@ sub new {
     return $self;
 }
 
-our $AUTOLOAD;
-sub AUTOLOAD {
-    my $self = shift;
-
-    ref($self) and eval { $self->isa(__PACKAGE__) }
-        or croak "Invalid method call";
-
-    my $field = $AUTOLOAD;
-    $field =~ s/.+:://;
-
-    if ( $field eq 'DESTROY' ) {
-        return eval { $self->SUPER::DESTROY(@_) };
-    }
-
-    $self->looks_like_an_x_field($field)
-        or croak "Invalid field '$field' requested";
-
-    Sub::Install::install_sub({
-            code => sub {
-                my $self = shift;
-                if (@_) {
-                    $self->set( $field, @_ );
-                }
-                else {
-                    $self->get($field);
-                }
-            },
-            into => ref($self),
-            as => $field,
-        });
-
-    $self->$field(@_);
-}
-
 =head1 METHODS
 
 =over
@@ -174,14 +121,10 @@ Returns true if I<$field> contains a list of dependencies. By default returns tr
 
 =item Build_Depends_Indep
 
-=item Build_Depends_Arch
-
 =item Build_Conflicts
 
 =item Build_Conflicts_Indep
 
-=item Build_Conflicts_Arch
-
 =item Depends
 
 =item Conflicts
@@ -204,9 +147,8 @@ Returns true if I<$field> contains a list of dependencies. By default returns tr
 
 our %dependency_list = map(
     ( $_ => 1 ),
-    qw( Build-Depends Build-Depends-Indep Build-Depends-Arch Build-Conflicts
-        Build-Conflicts-Indep Build-Conflicts-Arch Depends Conflicts Enhances
-        Replaces Breaks Pre-Depends Recommends Suggests ),
+    qw( Build-Depends Build-Depends-Indep Build-Conflicts Build-Conflicts-Indep
+    Depends Conflicts Enhances Replaces Breaks Pre-Depends Recommends Suggests ),
 );
 
 sub is_dependency_list {
@@ -250,19 +192,6 @@ sub is_comma_separated {
     return exists $comma_separated{$field};
 }
 
-=item looks_like_an_x_field($field)
-
-Returns true if B<$field> is considered appropriate to name a user-defined
-field.
-
-=cut
-
-sub looks_like_an_x_field {
-    my ( $self, $field ) = @_;
-
-    return $field =~ /^X[SBC]*(?:_[A-Z][A-Za-z0-9]*)+$/;
-}
-
 =item get($field)
 
 Overrides the default get method from L<Class::Accessor> with L<Tie::IxHash>'s
@@ -383,9 +312,7 @@ sub as_string
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (C) 2009, 2017 Damyan Ivanov L<dmn@debian.org>
-
-Copyright (C) 2020 gregor herrmann L<gregoa@debian.org>
+Copyright (C) 2009 Damyan Ivanov L<dmn@debian.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
