@@ -55,16 +55,8 @@ replaced with underscores.
 
 =item Provides
 
-=item Built_Using
-
-=item Multi_Arch
-
 =item Description
 
-=item Package_Type
-
-=item Build_Profiles
-
 =back
 
 C<Depends>, C<Conflicts> C<Breaks>, C<Recommends>, C<Suggests>, C<Enhances>,
@@ -95,15 +87,14 @@ package Debian::Control::Stanza::Binary;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 use base 'Debian::Control::Stanza';
 
 use constant fields => qw(
     Package Architecture Section Priority Essential Depends Recommends Suggests
-    Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using
-    Multi_Arch Package_Type Description _short_description _long_description
-    Build_Profiles
+    Enhances Replaces Pre_Depends Conflicts Breaks Provides Built_Using Description
+    _short_description _long_description
 );
 
 =head1 CONSTRUCTOR
