@@ -3,17 +3,13 @@ package Debian::Dependency;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 use AptPkg::Config;
 use Carp;
 use Dpkg::Version ();
 use List::MoreUtils qw(mesh);
 
-# Temporarily disable the warning until dpkg 1.20.x, as our usage is correct.
-no if $Dpkg::Version::VERSION ge '1.02',
-   warnings => qw(Dpkg::Version::semantic_change::overload::bool);
-
 =head1 NAME
 
 Debian::Dependency - dependency relationship between Debian packages
@@ -33,7 +29,7 @@ Debian::Dependency - dependency relationship between Debian packages
    print $d->ver;  # '5.10'
 
                                     # for people who like to type much
-   my $d = Debian::Dependency->new( { pkg => 'perl', ver => '5.10', profile => '!nocheck' } );
+   my $d = Debian::Dependency->new( { pkg => 'perl', ver => '5.10' } );
 
    # stringification
    print "$d"      # 'perl (>= 5.10)'
@@ -45,7 +41,7 @@ Debian::Dependency - dependency relationship between Debian packages
 =cut
 
 use base qw(Class::Accessor);
-__PACKAGE__->mk_accessors(qw( pkg ver rel profile alternatives ));
+__PACKAGE__->mk_accessors(qw( pkg ver rel alternatives ));
 
 use Carp;
 
@@ -61,14 +57,14 @@ use overload '""' => \&_stringify,
 
 Construct a new instance.
 
-=item new( { pkg => 'package', rel => '>=', ver => '1.9', profile => '!nocheck' } )
+=item new( { pkg => 'package', rel => '>=', ver => '1.9' } )
 
 If a hash reference is passed as an argument, its contents are used to
-initialize the object. Only C<pkg> is required.
+initialize the object.
 
 =item new( [ { pkg => 'foo' }, 'bar (<= 3)' ] );
 
-If an array reference is passed as an argument, its elements are used for
+In an array reference is passed as an argument, its elements are used for
 constructing a dependency with alternatives.
 
 =item new('foo (= 42)')
@@ -94,13 +90,12 @@ sub new {
     $class = ref($class) if ref($class);
 
     my $self = $class->SUPER::new();
-    my( $pkg, $rel, $ver, $profile );
+    my( $pkg, $rel, $ver );
 
     if( ref($_[0]) and ref($_[0]) eq 'HASH' ) {
         $pkg = delete $_[0]->{pkg};
         $rel = delete $_[0]->{rel} // '>=';
         $ver = delete $_[0]->{ver};
-        $profile = delete $_[0]->{profile};
         # pass-through the rest
         while( my($k,$v) = each %{$_[0]} ) {
             $self->$k($v);
@@ -140,11 +135,6 @@ sub new {
         delete $self->{ver};
     };
 
-    $self->profile($profile);
-    unless( defined( $self->profile ) ) {
-        delete $self->{profile};
-    };
-
     if ($rel) {
         $rel = '<=' if $rel eq '<';
         $rel = '>=' if $rel eq '>';
@@ -165,10 +155,11 @@ sub _stringify {
         return join( ' | ', @{ $self->alternatives } );
     }
 
-    my $depstring = $self->pkg;
-    $depstring .= ' (' . $self->rel . ' ' . $self->ver . ')' if $self->ver;
-    $depstring .= ' <' . $self->profile . '>' if $self->profile;
-    return $depstring;
+    return (
+          $self->ver
+        ? $self->pkg . ' (' . $self->rel . ' ' . $self->ver . ')'
+        : $self->pkg
+    );
 }
 
 sub _add {
@@ -278,8 +269,6 @@ Examples:
 
 =item libversion-perl (<< 3.4)
 
-=item libfoo (>= 23) [amd64] <stage1 !cross>
-
 =back
 
 =cut
@@ -326,16 +315,6 @@ sub parse {
                     )+
                 \]
             )?
-            (?:             # "restriction formulas" (build profile) is optional
-                \s*         # optional space
-                <
-                    (
-                        !?             # negation is optional
-                        [^\s>]+        # build profile name
-                        (?:\s+|(?=>) ) # whitespace or end
-                    )+
-                >
-            )*              # can appear several times
             $}x    # done
         )
     {
@@ -344,15 +323,11 @@ sub parse {
                 (     ( defined($2) and defined($3) )
                     ? ( rel => $2, ver => $3 )
                     : ()
-                ),
-                (     ( defined($4) )
-                    ? ( profile => $4 )
-                    : ()
                 )
             }
         );
     }
-    elsif ($str =~ /\S/) {
+    else {
         die "Unable to parse '$str'";
     }
 }
@@ -389,14 +364,6 @@ Examples
     print $dep->pkg;
     $dep->ver('3.4');
 
-=over
-
-=item profile
-
-Contains the "restriction formulas" (build profile) of a dependency; optional.
-
-=back
-
 =head1 METHODS
 
 =over
@@ -446,16 +413,6 @@ sub satisfies {
     # different package?
     return 0 unless $self->pkg eq $dep->pkg;
 
-    # packages differ in profile?
-    return 0                                    # $self does not satisfy $dep if
-        if (
-        ( !$self->profile && $dep->profile )    # self doesn't have a profile but $dep does, or
-        || ($self->profile                      # both have profiles but different ones
-            && $dep->profile
-            && $self->profile ne $dep->profile
-        )
-        );
-
     # $dep has no relation?
     return 1 unless $dep->rel;
 
@@ -560,8 +517,6 @@ L<Debian::Dependencies>
 
 =item Copyright (C) 2008,2009,2010 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2019 gregor herrmann <gregoa@debian.org>
-
 =back
 
 This program is free software; you can redistribute it and/or modify it under
