@@ -2,7 +2,7 @@ package Debian::WNPP::Query;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 =head1 NAME
 
@@ -51,11 +51,11 @@ use Storable ();
 use WWW::Mechanize ();
 
 our %list_url = (
-    ITP => 'https://www.debian.org/devel/wnpp/being_packaged',
-    RFP => 'https://www.debian.org/devel/wnpp/requested',
-    ITA => 'https://www.debian.org/devel/wnpp/being_adopted',
-    RFA => 'https://www.debian.org/devel/wnpp/rfa_bypackage',
-    O   => 'https://www.debian.org/devel/wnpp/orphaned',
+    ITP => 'http://www.debian.org/devel/wnpp/being_packaged',
+    RFP => 'http://www.debian.org/devel/wnpp/requested',
+    ITA => 'http://www.debian.org/devel/wnpp/being_adopted',
+    RFA => 'http://www.debian.org/devel/wnpp/rfa_bypackage',
+    O   => 'http://www.debian.org/devel/wnpp/orphaned',
 );
 
 sub new {
@@ -118,7 +118,7 @@ sub _fetch {
         }
 
         for my $link ( $browser->links ) {
-            next unless $link->url =~ m{^https://bugs.debian.org/(\d+)};
+            next unless $link->url =~ m{^http://bugs.debian.org/(\d+)};
 
             my $bug = $1;
 
