@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 use feature 'switch';
 
@@ -31,25 +31,21 @@ use Config::INI::Reader ();
 use CPAN ();
 use CPAN::Meta;
 use Cwd qw( getcwd );
-use Dpkg;
-use Dpkg::Index;
-use Dpkg::Control::Types;
 use Debian::Control::FromCPAN;
 use Debian::Dependencies;
 use Debian::Rules;
 use DhMakePerl::PodParser ();
-use Dpkg::Changelog::Debian;
-use Email::Address::XS 1.01;
 use File::Basename qw(basename dirname);
 use File::Find qw(find);
 use File::Path ();
 use File::Which;
 use File::Spec::Functions qw(catfile catpath splitpath);
+use Parse::DebianChangelog;
 use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
 
-use constant debstdversion => '4.6.1';
+use constant debstdversion => '3.9.8';
 
 our %DEFAULTS = (
 );
@@ -123,48 +119,33 @@ sub makefile_pl {
     return $self->main_file('Makefile.PL');
 }
 
-sub get_user {
-    return $ENV{LOGNAME} || $ENV{USER};
-}
-
-sub get_email {
+sub get_developer {
     my $self = shift;
+
     my $email = $self->cfg->email;
 
-    $email ||= ( $ENV{DEBEMAIL} || $ENV{EMAIL} );
-    unless ($email) {
-	my $mailh;
-        chomp( $mailh = `cat /etc/mailname` );
-        $email = $self->get_user . '@' . $mailh;
-    }
-
-    $email =~ s/^(.*)\s+<(.*)>$/$2/;
-    return $email;
-}
-
-sub get_name {
-    my $self = shift;
-
-    my $name;
-    my $user = $self->get_user;
-    my $pwnam = getpwuid($<);
+    my ( $user, $pwnam, $name, $mailh );
+    $user = $ENV{LOGNAME} || $ENV{USER};
+    $pwnam = getpwuid($<);
     die "Cannot determine current user\n" unless $pwnam;
     if ( defined $ENV{DEBFULLNAME} ) {
         $name = $ENV{DEBFULLNAME};
     }
     else {
         $name = $pwnam->gecos;
-        $name =~ s/\n/ /g;
         $name =~ s/,.*//;
     }
     $user ||= $pwnam->name;
     $name ||= $user;
-    return $name;
-}
+    $email ||= ( $ENV{DEBEMAIL} || $ENV{EMAIL} );
+    unless ($email) {
+        chomp( $mailh = `cat /etc/mailname` );
+        $email = $user . '@' . $mailh;
+    }
 
-sub get_developer {
-    my $self = shift;
-    return $self->get_name . " <" . $self->get_email . ">";
+    $email =~ s/^(.*)\s+<(.*)>$/$2/;
+
+    return "$name <$email>";
 }
 
 sub fill_maintainer {
@@ -180,9 +161,9 @@ sub fill_maintainer {
             my $old_maint = $src->Maintainer;
             $src->Maintainer($pkg_perl_maint);
             $src->Uploaders->add($old_maint) if $old_maint;
-            $src->Uploaders->add($maint);
         }
 
+        $src->Uploaders->add($maint);
     }
     else {
         $src->Maintainer($maint);
@@ -273,7 +254,7 @@ sub get_wnpp {
     return undef unless $self->cfg->network;
 
     my $wnpp = Debian::WNPP::Query->new(
-        { cache_file => catfile( $self->cfg->cache_dir, 'wnpp.cache' ) } );
+        { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } );
     my @bugs = $wnpp->bugs_for_package($package);
     return $bugs[0];
 }
@@ -298,6 +279,9 @@ sub extract_basic {
         find( sub { $self->check_for_xs }, $self->main_dir );
     }
 
+    $self->cfg->dh('9')
+        if not $self->cfg->_explicitly_set->{dh};
+
     printf(
         "Found: %s %s (%s arch=%s)\n",
         $self->perlname, $self->version,
@@ -372,14 +356,8 @@ sub extract_name_ver {
         $ver  = $self->version;
     }
 
-    if ($self->cfg->version) {
-        #Version specified on command line trumps other versions
-        $ver = $self->cfg->version
-    } elsif ( $self->mod_cpan_version ) {
-        if ($self->mod_cpan_version != $ver) {
-            die "Version ambiguity, cpan has ".$self->mod_cpan_version.", module has ".$ver.". Please specify version with --version.\n";
-        }
-    }
+    $ver = $self->cfg->version
+        if $self->cfg->version;
 
     # final sanitazing of name and version
     $name =~ s/::/-/g if defined $name;
@@ -683,16 +661,16 @@ sub extract_desc {
     my ( $self, $file ) = @_;
 
     my $bin = $self->control->binary_tie->Values(0);
-    my $short_desc = $bin->short_description;
+    my $desc = $bin->short_description;
 
-    $short_desc and return;
+    $desc and return;
 
     return unless -f $file;
     my ( $parser, $modulename );
     $parser = new DhMakePerl::PodParser;
     $parser->set_names(qw(NAME DESCRIPTION DETAILS));
     $parser->parse_from_file($file);
-    if ( $short_desc ) {
+    if ( $desc ) {
 
         # No-op - We already have it, probably from the command line
 
@@ -700,7 +678,7 @@ sub extract_desc {
     elsif ( $self->meta->{abstract} ) {
 
         # Get it from META.yml
-        $short_desc = $self->meta->{abstract};
+        $desc = $self->meta->{abstract};
 
     }
     elsif ( my $my_desc = $parser->get('NAME') ) {
@@ -711,21 +689,20 @@ sub extract_desc {
         $my_desc =~ s/\s+$//s;
         $my_desc =~ s/^([^\s])/ $1/mg;
         $my_desc =~ s/\n.*$//s;
-        $short_desc = $my_desc;
+        $desc = $my_desc;
     }
 
-    if ( defined($short_desc) ) {
+    if ( defined($desc) ) {
         # Replace linefeed (not followed by a space) in short description with
         # spaces
-        $short_desc =~ s/\n(?=\S)/ /gs;
-        $short_desc =~ s/^\s+//;                   # strip leading spaces
-        $short_desc =~ s/^(?:(A|An|The))\s+//i;    # strip leading article
+        $desc =~ s/\n(?=\S)/ /gs;
+        $desc =~ s/^\s+//;      # strip leading spaces
     }
 
     # have a fall-back for the short description
-    $short_desc ||= '(no short description found)';
+    $desc ||= '(no short description found)';
 
-    $bin->short_description($short_desc);
+    $bin->short_description($desc);
 
     my $long_desc;
     unless ( $bin->long_description ) {
@@ -734,7 +711,8 @@ sub extract_desc {
             || $parser->get('DETAILS')
             || '';
         ( $modulename = $self->perlname ) =~ s/-/::/g;
-        $long_desc =~ s/This (?:module|library|plugin)/$modulename/;
+        $long_desc =~ s/This module/$modulename/;
+        $long_desc =~ s/This library/$modulename/;
 
         local ($Text::Wrap::columns) = 78;
         $long_desc = fill( "", "", $long_desc );
@@ -818,8 +796,6 @@ sub extract_docs {
     my $dir = $self->main_dir;
 
     $dir .= '/' unless $dir =~ m(/$);
-
-    my $toplevelreadme_re = quotemeta($self->main_dir) . '/README(?:\.\w+)?$';
     find(
         {   preprocess => sub {
                 my $bn = basename $File::Find::dir;
@@ -836,14 +812,14 @@ sub extract_docs {
                     substr( $File::Find::name, length($dir) )
                     )
                     if (
-                        $File::Find::name !~ m{$toplevelreadme_re}i
-                    and /^\b(README|TODO|BUGS|NEWS|ANNOUNCE|CONTRIBUTING|CODE_OF_CONDUCT)\b/i
+                        $File::Find::name ne $self->main_dir . '/README'
+                    and /^\b(README|TODO|BUGS|NEWS|ANNOUNCE|CONTRIBUTING)\b/i
                     and !/\.(pod|pm)$/
                     and ( !$self->cfg->exclude
                         or $File::Find::name !~ $self->cfg->exclude )
                     and !/\.svn-base$/
                     and $File::Find::name
-                    !~ m{debian/(README\.(?:source|[Dd]ebian)|NEWS)}
+                    !~ m{debian/README\.(?:source|[Dd]ebian)}
                     );
             },
         },
@@ -896,12 +872,10 @@ sub create_rules {
 
     $self->backup_file($file);
 
-    my $arch = $self->control->binary_tie->Values(0)->Architecture;
-    my $rulesname
-        = ( $arch eq 'all' ? 'rules.dh.tiny.all' : 'rules.dh.tiny.any' );
+    my $rulesname = 'rules.dh.tiny';
 
     for my $source (
-        catfile( $self->cfg->config_dir, $rulesname ),
+        catfile( $self->cfg->home_dir, $rulesname ),
         catfile( $self->cfg->data_dir, $rulesname )
     ) {
         if ( -e $source ) {
@@ -914,6 +888,14 @@ sub create_rules {
     chmod( 0755, $file ) or die "chmod($file): $!";
 }
 
+sub create_compat {
+    my ( $self, $file ) = @_;
+
+    my $fh = $self->_file_w($file);
+    $fh->print( $self->cfg->dh, "\n" );
+    $fh->close;
+}
+
 sub update_file_list( $ % ) {
     my ( $self, %p ) = @_;
 
@@ -923,22 +905,34 @@ sub update_file_list( $ % ) {
         next unless @$new_content;
         # pkgname.foo file
         my $pkg_file = $self->debian_file("$pkgname.$file");
-        my @content;
-        tie @content, 'Array::Unique';
+        my %uniq_content;
+        my @existing_content;
 
         # if a package.foo exists read its values first
         if ( -r $pkg_file ) {
             my $fh                = $self->_file_r($pkg_file);
-            @content = $fh->getlines;
-            chomp(@content);
+            @existing_content = $fh->getlines;
+            chomp(@existing_content);
+
+            # make list of files for package.foo unique
+            $uniq_content{$_} = 1 for @existing_content;
         }
 
-        push @content, @$new_content;
-        @content = sort @content;
+        $uniq_content{$_} = 1 for @$new_content;
 
-        # write package.foo file
+        # write package.foo file with unique entries
         open F, '>', $pkg_file or die $!;
-        print F "$_\n" for @content;
+        for ( @existing_content, @$new_content ) {
+
+            # we have the unique hash
+            # we delete from it each printed line
+            # so if a line is not in the hash, this means we have already
+            # printed it
+            next unless exists $uniq_content{$_};
+
+            delete $uniq_content{$_};
+            print F "$_\n";
+        }
         close F;
     }
 }
@@ -995,8 +989,7 @@ sub create_copyright {
     # Absence of author should have already been reported in the
     # Header section
     push @res,
-        'Copyright: ' . ( $cprt_year ? $cprt_year : '<INSERT COPYRIGHT YEAR(S) HERE>' )
-        . ", $cprt_author";
+        "Copyright: " . ( $cprt_year ? "$cprt_year, " : '' ) . $cprt_author;
 
     # This is far from foolproof, but usually works with most
     # boilerplate-generated modules.
@@ -1064,7 +1057,7 @@ sub create_copyright {
             " Licensed under the Apache License, Version 2.0 (the \"License\");\n"
             . " you may not use this file except in compliance with the License.\n"
             . " You may obtain a copy of the License at\n"
-            . "     https://www.apache.org/licenses/LICENSE-2.0\n"
+            . "     http://www.apache.org/licenses/LICENSE-2.0\n"
             . " Unless required by applicable law or agreed to in writing, software\n"
             . " distributed under the License is distributed on an \"AS IS\" BASIS,\n"
             . " WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.\n"
@@ -1198,38 +1191,55 @@ sub upsurl {
 }
 
 
+my $ACTUAL_NAME_RE = '\pL[\s\pL\-\'\.]*\pL';
+
+# See http://www.faqs.org/rfcs/rfc2822.html
+# Section 3.4.1
+use Email::Address;
+my $EMAIL_RE = $Email::Address::addr_spec;
+
+my $EMAIL_CHANGES_RE = qr{
+    ^                           # beginining of line
+    \s+\*\s                     # item marker
+    Email\schange:\s            # email change token
+    ($ACTUAL_NAME_RE)           # actual name
+    \s+->\s+                    # gap between name and email
+    ($EMAIL_RE)                 # email address
+    $                           # end of line
+}xms;
+
+my $PERSON_PARSE_RE = qr{
+    \A                          # beginining of string
+    ($ACTUAL_NAME_RE)           # actual name
+    \s                          # gap
+    \<$EMAIL_RE\>               # logged email
+    \z                          # end of string
+}xms;
+
 # This is what needs fixing.
 sub copyright_from_changelog {
     my ( $self, $firstmaint, $firstyear ) = @_;
     my %maintainers = ();
     @{ $maintainers{$firstmaint} } = ($firstyear);
-    my $chglog = Dpkg::Changelog::Debian->new( range => { "all" => 1 } );
-    $chglog->load($self->debian_file('changelog')) or die "Parse error\n";
+    my $chglog = Parse::DebianChangelog->init(
+        { infile => $self->debian_file('changelog') } );
     my %email_changes = ();
-    foreach ( @{$chglog} ) {
-        my $person      = $_->get_maintainer();
-        my $year        = $_->get_timepiece()->year;
-        my $changes     = $_->get_part('changes');
-        if (ref $changes eq 'ARRAY') {
-            $changes = join("\n", @$changes);
-        }
-        if (my %changes = ($changes =~ m/^\s+\*\sEmail\schange:\s+(.*?)\s+->\s+(.*?)\s*$/xmsg)) {
+    foreach ( $chglog->data() ) {
+        my $person      = $_->Maintainer;
+        my $date        = $_->Date;
+        my @date_pieces = split( " ", $date );
+        my $year        = $date_pieces[3];
+        if (my %changes = ($_->Changes =~ m/$EMAIL_CHANGES_RE/xmsg)) {
             # This way round since we are going backward in time thru changelog
             foreach my $p (keys %changes) {
-                # Parse bare email address; undef if it not an email address
-                my $address = Email::Address::XS->parse_bare_address($changes{$p})->address();
-                if ($address) {
-                    $changes{$p} = $address;
-                } else {
-                    delete $changes{$p};
-                }
+                $changes{$p} =~ s{[\s\n]+$}{}xms;
             }
             %email_changes = (
                 %changes,
                 %email_changes
             );
         }
-        if (my $name = Email::Address::XS->parse($person)->phrase()) {
+        if (my ($name) = ($person =~ $PERSON_PARSE_RE)) {
             if (exists $email_changes{$name}) {
                 $person = "$name <$email_changes{$name}>";
             }
@@ -1297,7 +1307,7 @@ sub write_source_format {
 sub module_build {
     my $self = shift;
 
-    # use Build.PL even if there's a Makefile.PL which is a
+    # dehbelper prefers Makefile.PL over Build.PL unless the former is a
     # Module::Build::Compat wrapper
     return 'Module-Build' if $self->makefile_pl_is_MBC;
 
@@ -1375,16 +1385,25 @@ sub discover_dependencies {
         my $wnpp_query;
         $wnpp_query
             = Debian::WNPP::Query->new(
-            { cache_file => catfile( $self->cfg->cache_dir, 'wnpp.cache' ) } )
+            { cache_file => catfile( $self->cfg->home_dir, 'wnpp.cache' ) } )
             if $self->cfg->network;
 
         # control->discover_dependencies needs configured CPAN
         $self->configure_cpan;
 
+        # Attempt to get an instance of DPKG::Parse::Available. If this
+        # isn't available, warn the user, as versions of packages cannot
+        # be checked.
         # Don't cache this in case we've built and installed a
         # module in this instance.
-        my $dpkg_available = Dpkg::Index->new(type => CTRL_INFO_PKG);
-        $dpkg_available->load("$Dpkg::ADMINDIR/available");
+        my $dpkg_available;
+        if ( eval { require DPKG::Parse::Available } && DPKG::Parse->VERSION >= 0.02 ) {
+            $dpkg_available = DPKG::Parse::Available->new;
+            $dpkg_available->parse;
+        } else {
+            warn "DPKG::Parse v0.02 or higher not found.";
+            warn "Versions of required packages will not be checked.";
+        }
 
         return $self->control->discover_dependencies(
             {   dir                => $self->main_dir,
@@ -1396,7 +1415,6 @@ sub discover_dependencies {
                 install_build_deps => $self->cfg->install_build_deps,
                 wnpp_query         => $wnpp_query,
                 intrusive          => $self->cfg->intrusive,
-                guess_nocheck      => $self->cfg->guess_nocheck,
             }
         );
     }
@@ -1410,7 +1428,7 @@ sub discover_dependencies {
     }
     else {
         warn "No APT contents can be loaded.\n";
-        warn "Please install the 'apt-file' package (at least version 3) and\n";
+        warn "Please install 'apt-file' package (at least version 2.5.0) and\n";
         warn "run 'apt-file update' as root.\n";
         warn "Dependencies not updated.\n";
 
@@ -1430,7 +1448,7 @@ The following special cases are detected:
 =item Module::Build::Tiny
 
 if L<Module::Build::Tiny> is present in the build-dependencies, debhelper
-dependency is raised to 9.20140227~ in case it was lower before.
+dependency is raised to 9.20140227~.
 
 =item dh --with=quilt
 
@@ -1441,13 +1459,14 @@ C<dh --with=quilt> needs quilt.
 If F</usr/share/quilt/quilt.make> is included in F<debian/rules>, a
 build-dependency on C<quilt> is added.
 
-=item dh --with=perl_dbi
+=item Module::Build
 
-A build dependency on C<libdbi-perl> is added.
+The proper build-dependency in this case is
 
-=item dh --with=perl_openssl
+    perl
 
-A build dependency on C<perl-openssl-defaults> is added.
+The on perl without a version is set as Lenny has already 5.10 which
+includes first Module::Build.
 
 =back
 
@@ -1471,25 +1490,20 @@ sub discover_utility_deps {
         $build_deps_indep->add('perl');
     }
     else {
-        $build_deps->remove('perl');
-        $build_deps->add('perl:native');
-        $build_deps->add('perl-xs-dev');
+        $build_deps->add('perl');
     }
-    $build_deps->add( Debian::Dependency->new( 'debhelper-compat', '=', $debhelper_version ) );
+    $build_deps->add( Debian::Dependency->new( 'debhelper', $debhelper_version ) );
+
+    $self->explained_dependency( 'Module::Build::Tiny', $build_deps,
+        'debhelper (>= 9.20140227~)' )
+        if $build_deps->has('libmodule-build-tiny-perl');
 
     for ( @{ $self->rules->lines } ) {
         $self->explained_dependency(
             'dh --with=quilt',
-            $build_deps,
-            'quilt'
+            $build_deps, 'quilt',
         ) if /dh\s+.*--with[= ]quilt/;
 
-        $self->explained_dependency(
-            'quilt.make',
-            $build_deps,
-            'quilt'
-        ) if m{^include /usr/share/quilt/quilt.make};
-
         $self->explained_dependency(
             'dh --with=bash-completion',
             $build_deps,
@@ -1502,29 +1516,20 @@ sub discover_utility_deps {
             'libdbi-perl'
         ) if (/dh\s+.*--with[= ]perl[-_]dbi/);
 
-        $self->explained_dependency(
-            'dh --with=perl_openssl',
-            $build_deps,
-            'perl-openssl-defaults'
-        ) if (/dh\s+.*--with[= ]perl[-_]openssl/);
+        $self->explained_dependency( 'quilt.make', $build_deps, 'quilt' )
+            if m{^include /usr/share/quilt/quilt.make};
+
     }
 
-    # Ensure libmodule-build{,tiny}-perl/libmodule-build-using-pkgconfig-perl
-    # and perl are in B-D (and not in B-D-I).
+    # Ensure both libmodule-build-perl and perl are in B-D
+    # (and not in B-D-I).
     if ( $self->module_build eq 'Module-Build' ) {
-        my ($mb)   = $build_deps_indep->remove('libmodule-build-perl');
-        my ($mbt)  = $build_deps_indep->remove('libmodule-build-tiny-perl');
-        my ($mbup) = $build_deps_indep->remove('libmodule-build-using-pkgconfig-perl');
-        my ($perl) = $build_deps_indep->remove('perl');
-        $perl ||= ( $architecture eq 'all' ? 'perl' : 'perl:native' );
+        $build_deps_indep->remove('libmodule-build-perl');
+        $build_deps_indep->remove('perl');
         $self->explained_dependency( 'Module::Build', $build_deps,
-            "$mb" ) if $mb;
-        $self->explained_dependency( 'Module::Build::Tiny', $build_deps,
-            "$mbt" ) if $mbt;
-        $self->explained_dependency( 'Module::Build::Using::PkgConfig', $build_deps,
-            "$mbup" ) if $mbup;
-        $self->explained_dependency( 'Module::Build{,::Tiny}', $build_deps,
-            "$perl" );
+            'libmodule-build-perl' );
+        $self->explained_dependency( 'Module::Build', $build_deps,
+            'perl' );
     }
 
     # some mandatory dependencies
@@ -1597,8 +1602,7 @@ sub unquote {
 
 =item create_upstream_metadata
 
-Populates F<debian/upstream/metadata> with information from F<META>,
-using L<Debian::Upstream::Metadata::Perl>.
+Populates F<debian/upstream/metadata> with information from F<META>.
 
 =cut
 
@@ -1608,49 +1612,27 @@ sub create_upstream_metadata {
 
     return unless %$meta;
 
-    require Debian::Upstream::Metadata::Perl;
-    Debian::Upstream::Metadata::Perl->convert(
-        $self->meta,
-        File::Spec->catfile(
-            $self->main_dir, 'debian', 'upstream', 'metadata'
-        )
-    );
-}
+    require YAML::XS;
 
-=item cme_fix_dpkg_control
+    my %upstream;
 
-The equivalent of letting cme(1) reformat and fix F<debian/control>.
+    $upstream{"Archive"}           = 'CPAN';
+    $upstream{"Name"}              = $meta->{name};
+    $upstream{"Contact"}           = join( ', ', @{ $meta->{author} } );
+    # $upstream{"Homepage"}        = $meta->{resources}->{homepage};
+    $upstream{"Bug-Database"}      = $meta->{resources}->{bugtracker}->{web};
+    $upstream{"Bug-Submit"}        = $meta->{resources}->{bugtracker}->{mailto};
+    $upstream{"Repository"}        = $meta->{resources}->{repository}->{url};
+    $upstream{"Repository-Browse"} = $meta->{resources}->{repository}->{web};
 
-=cut
-
-sub cme_fix_dpkg_control {
-    my ( $self, $dir ) = @_;
-
-    if (eval {
-            require Config::Model;
-            require Config::Model::Dpkg;
-        }
-        )
-    {
-        print "I: Using Config::Model::Dpkg\n" if $self->cfg->verbose;
-        if ( !$self->cfg->network ) {
-            warn "W: Config::Model::Dpkg needs network access, and we are running with --no-network";
-            return;
-        }
-        my $model    = Config::Model->new();
-        my $instance = $model->instance(
-            root_class_name => 'Dpkg::Control',
-            root_dir        => $dir,
-        );
-
-        # potentially apply fixes
-        $instance->apply_fixes();
-        # force write even without changes to get reformatting
-        $instance->save( force => 1 );
-    } else {
-        warn
-            "W: Config::Model::Dpkg not found. You might want to install libconfig-model-dpkg-perl";
+    foreach ( keys %upstream ) {
+        delete $upstream{$_} unless defined $upstream{$_};
     }
+
+    my $dir = File::Spec->catdir( $self->main_dir, 'debian', 'upstream' );
+
+    mkdir($dir);
+    YAML::XS::DumpFile( File::Spec->catfile( $dir, 'metadata' ), \%upstream );
 }
 
 =back
@@ -1687,7 +1669,7 @@ sub _file_w {
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2021, gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2015 gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007-2013 Damyan Ivanov <dmn@debian.org>
 
@@ -1699,8 +1681,6 @@ sub _file_w {
 
 =item Copyright (c) 2016, Nick Morrott <knowledgejunkie@gmail.com>
 
-=item Copyright (c) 2017, David Miguel Susano Pinto <carandraug+dev@gmail.com>
-
 =back
 
 This program is free software; you can redistribute it and/or modify it under
