@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -40,7 +40,7 @@ TO BE FILLED
 =cut
 
 use CPAN ();
-use Cwd qw( realpath cwd );
+use Cwd qw( realpath );
 use Debian::Dependencies      ();
 use Debian::Dependency        ();
 use Debian::WNPP::Query;
@@ -84,11 +84,11 @@ sub execute {
 
     $tarball //= $self->guess_debian_tarball if $self->cfg->{vcs} eq 'git';
 
-    if ( defined $self->cfg->revision ) {
-        $self->pkgversion( $self->version . '-' . $self->cfg->revision );
+    unless ( defined $self->cfg->version ) {
+        $self->pkgversion( $self->version . '-1' );
     }
     else {
-        $self->pkgversion( $self->version . '-1' );
+        $self->pkgversion( $self->cfg->version );
     }
 
     $self->fill_maintainer;
@@ -130,16 +130,12 @@ sub execute {
     my $src = $self->control->source;
 
     $src->Testsuite('autopkgtest-pkg-perl') if $self->cfg->{pkg_perl};
-    $src->Rules_Requires_Root('no');
 
     my @missing = $self->discover_dependencies;
 
     $bin->Depends->add( $self->cfg->depends )
         if $self->cfg->depends;
 
-    $bin->Depends( Debian::Dependencies->new( $self->cfg->force_depends ) )
-        if $self->cfg->force_depends;
-
     $src->Build_Depends->add( $self->cfg->bdepends )
         if $self->cfg->bdepends;
 
@@ -182,13 +178,23 @@ sub execute {
     $src->Homepage( $self->upsurl );
     if ( $self->cfg->pkg_perl ) {
         my $vcs = lc( $self->cfg->vcs );
-        if ( $vcs eq 'git' ) {
-            $self->control->source->Vcs_Git(
-                sprintf( "https://salsa.debian.org/perl-team/modules/packages/%s.git",
+        if ( $vcs eq 'svn' ) {
+            $self->control->source->Vcs_Svn(
+                sprintf( "svn://svn.debian.org/pkg-perl/trunk/%s/",
                     $self->pkgname )
             );
             $self->control->source->Vcs_Browser(
-                sprintf( "https://salsa.debian.org/perl-team/modules/packages/%s",
+                sprintf( "http://anonscm.debian.org/viewvc/pkg-perl/trunk/%s/",
+                    $self->pkgname )
+            );
+        }
+        elsif ( $vcs eq 'git' ) {
+            $self->control->source->Vcs_Git(
+                sprintf( "https://anonscm.debian.org/git/pkg-perl/packages/%s.git",
+                    $self->pkgname )
+            );
+            $self->control->source->Vcs_Browser(
+                sprintf( "https://anonscm.debian.org/cgit/pkg-perl/packages/%s.git",
                     $self->pkgname )
             );
         }
@@ -197,8 +203,8 @@ sub execute {
         }
     }
     $self->control->write( $self->debian_file('control') );
-    $self->cme_fix_dpkg_control( $self->main_dir );
 
+    $self->create_compat( $self->debian_file('compat') );
     $self->create_watch( $self->debian_file('watch') );
 
     #create_readme("$debiandir/README.Debian");
@@ -207,8 +213,6 @@ sub execute {
 
     $self->create_upstream_metadata;
 
-    $self->create_gbp_conf;
-
     if ( $self->cfg->recursive ) {
         $already_done //= {};
         my $mod_name = $self->perlname;
@@ -328,12 +332,6 @@ sub setup_dir {
         }
 
         $dist->get;     # <- here $ENV{'PWD'} gets set to $HOME/.cpan/build
-        # only in case $orig_pwd was not previously set, fall back to the first existing working path
-        # cf. MR!3 and #815390
-        if ( ! defined ($orig_pwd) ) {
-            $orig_pwd = $ENV{'PWD'};
-        }
-
         chdir $orig_pwd;   # so set it back
         $dist->pretty_id =~ /^(.)(.)/;
         $tarball = $CPAN::Config->{'keep_source_where'} . "/authors/id/$1/$1$2/";
@@ -402,25 +400,6 @@ sub build_package {
     my ( $self ) = @_;
 
     my $main_dir = $self->main_dir;
-
-    if ( my $build_script = $self->cfg->build_script ) {
-        my $save_cwd = cwd;
-        my $ok = eval {
-            chdir $self->main_dir
-                or die sprintf("chdir(%s): %s", $self->main_dir, "$!");
-
-            (system {$build_script} $build_script) == 0
-                or die "E: Build script failed\n";
-
-            1;
-        };
-        my $err = $@;
-        chdir $save_cwd or die sprintf("chdir(%s): %s", $save_cwd, "$!");
-
-        die $err unless $ok;
-        return;
-    }
-
     # warn if local::lib usage is detected. cf. #820395
     if ( $ENV{PERL_LOCAL_LIB_ROOT} ) {
         $self->warning('It seems that you are running in an active local::lib environment.');
@@ -432,10 +411,10 @@ sub build_package {
     }
     # uhmf! dpkg-genchanges doesn't cope with the deb being in another dir..
     #system("dpkg-buildpackage -b -us -uc " . $self->cfg->dbflags) == 0
-    system(qw(fakeroot make -C), $main_dir, qw(-f debian/rules clean));
-    system(qw(make -C), $main_dir, qw(-f debian/rules build)) == 0
+    system("fakeroot make -C $main_dir -f debian/rules clean");
+    system("make -C $main_dir -f debian/rules build") == 0
         || die "Cannot create deb package: 'debian/rules build' failed.\n";
-    system(qw(fakeroot make -C), $main_dir, qw(-f debian/rules binary)) == 0
+    system("fakeroot make -C $main_dir -f debian/rules binary") == 0
         || die "Cannot create deb package: 'fakeroot debian/rules binary' failed.\n";
 }
 
@@ -445,8 +424,8 @@ sub build_source_package {
     my $main_dir = $self->main_dir;
     # uhmf! dpkg-genchanges doesn't cope with the deb being in another dir..
     #system("dpkg-buildpackage -S -us -uc " . $self->cfg->dbflags) == 0
-    system(qw(fakeroot make -C), $main_dir, qw(-f debian/rules clean));
-    system(qw(dpkg-source -b), $main_dir) == 0
+    system("fakeroot make -C $main_dir -f debian/rules clean");
+    system("dpkg-source -b $main_dir") == 0
         || die "Cannot create source package: 'dpkg-source -b' failed.\n";
 }
 
@@ -469,21 +448,10 @@ sub install_package {
         $archspec );
 
     my $deb = $self->main_dir . "/../$debname";
-    my @install_cmd;
-    if ($self->cfg->install_with =~ /^apt(-get|itude)?$/) {
-        @install_cmd = ($self->cfg->install_with, 'install');
-    }
-    else {
-        @install_cmd = ($self->cfg->install_with, '-i');
-    }
-    push @install_cmd, $deb;
-
-    unshift @install_cmd, 'sudo' if $>;
-    {
-        local $, = ' ';
-        $self->info("Running '@install_cmd'...");
-    }
-    system(@install_cmd) == 0
+    my $dpkg_cmd = "dpkg -i $deb";
+    $dpkg_cmd = "sudo $dpkg_cmd" if $>;
+    $self->info("Running '$dpkg_cmd'...");
+    system($dpkg_cmd) == 0
         || die "Cannot install package $deb\n";
 }
 
@@ -559,7 +527,7 @@ sub create_changelog {
 
     $fh->printf( "%s (%s) %s; urgency=low\n",
         $self->srcname, $self->pkgversion, $changelog_dist );
-    $fh->print("\n  * Initial release.$closes\n\n");
+    $fh->print("\n  * Initial Release.$closes\n\n");
     $fh->printf( " -- %s  %s\n", $self->get_developer,
         email_date(time) );
 
@@ -584,23 +552,13 @@ sub create_watch {
 
     my $fh = $self->_file_w($filename);
 
-    my $version_re = 'v?@ANY_VERSION@@ARCHIVE_EXT@';
+    my $version_re = 'v?(\d[\d.-]*)\.(?:tar(?:\.gz|\.bz2)?|tgz|zip)';
 
-    $fh->printf( "version=4\n%s   .*/%s-%s\$\n",
+    $fh->printf( "version=3\n%s   .*/%s-%s\$\n",
         $self->upsurl, $self->perlname, $version_re );
     $fh->close;
 }
 
-sub create_gbp_conf {
-    my ($self) = @_;
-
-    my $fh = $self->_file_w($self->debian_file('gbp.conf'));
-    $fh->print("[DEFAULT]\n");
-    $fh->print("debian-branch = debian/latest\n");
-    $fh->close;
-
-}
-
 sub search_pkg_perl {
     my $self = shift;
 
@@ -617,15 +575,15 @@ sub search_pkg_perl {
     $ua->env_proxy;
     $ua->conn_cache( LWP::ConnCache->new );
 
-    my $packagesurl = "https://salsa.debian.org/perl-team/modules/packages/$pkg";
-    $resp = $ua->get($packagesurl);
+    $resp = $ua->get(
+        "https://anonscm.debian.org/cgit/pkg-perl/packages/$pkg.git");
     return { url => $resp->request->uri }
-        if $resp->is_success and $resp->request->uri eq $packagesurl;
+        if $resp->is_success;
 
-    my $atticurl = "https://salsa.debian.org/perl-team/modules/attic/$pkg";
-    $resp = $ua->get($atticurl);
+    $resp = $ua->get(
+        "https://anonscm.debian.org/cgit/pkg-perl/attic/$pkg.git");
     return { url => $resp->request->uri }
-        if $resp->is_success and $resp->request->uri eq $atticurl;
+        if $resp->is_success;
 
     return undef;
 }
@@ -786,27 +744,25 @@ sub git_import_upstream__init_debian {
     $self->reset_git_environment();
 
     Git::command( 'init', $self->main_dir );
-    my @git_config = ( '-c', 'user.name=' . $self->get_name,
-                       '-c', 'user.email=' . $self->get_email);
 
     my $git = Git->repository( $self->main_dir );
     $git->command( qw(symbolic-ref HEAD refs/heads/upstream) );
     $git->command( 'add', '.' );
-    $git->command( @git_config, 'commit', '-m',
+    $git->command( 'commit', '-m',
               "Import original source of "
             . $self->perlname . ' '
             . $self->version );
     $git->command( 'tag', "upstream/".$self->version, 'upstream' );
 
-    $git->command( qw( checkout -b debian/latest upstream ) );
+    $git->command( qw( checkout -b master upstream ) );
     if ( -d $self->debian_dir ) {
       # remove debian/ directory if the upstream ships it. This goes into the
-      # 'debian/upstream' branch, so the 'upstream' branch contains the original debian/
+      # 'master' branch, so the 'upstream' branch contains the original debian/
       # directory, and thus matches the pristine-tar. Here I also remove the
       # debian/ directory from the working tree; git has the history, so I don't
       # need the debian.bak
       $git->command( 'rm', '-r', $self->debian_dir );
-      $git->command( @git_config, 'commit', '-m',
+      $git->command( 'commit', '-m',
                      'Removed debian directory embedded in upstream source' );
     }
 }
@@ -820,30 +776,20 @@ sub git_add_debian {
     $self->reset_git_environment;
 
     my $git = Git->repository( $self->main_dir );
-    my $name = $self->get_name;
-    my $email = $self->get_email;
-    my @git_config = ( '-c', "user.name=$name",
-                       '-c', "user.email=$email");
     $git->command( 'add', 'debian' );
-    $git->command( @git_config, 'commit', '-m',
+    $git->command( 'commit', '-m',
         "Initial packaging by dh-make-perl $VERSION" );
     $git->command(
         qw( remote add origin ),
-        sprintf( "git\@salsa.debian.org:perl-team/modules/packages/%s.git",
+        sprintf( "ssh://git.debian.org/git/pkg-perl/packages/%s.git",
             $self->pkgname ),
     ) if $self->cfg->pkg_perl;
 
     if ( File::Which::which('pristine-tar') ) {
         if ( $tarball and -f $tarball ) {
             $ENV{GIT_DIR} = File::Spec->catdir( $self->main_dir, '.git' );
-            my %backup_ENV = %ENV;
-            $ENV{GIT_COMMITTER_NAME} = $name;
-            $ENV{GIT_COMMITTER_EMAIL} = $email;
-            $ENV{GIT_AUTHOR_NAME} = $name;
-            $ENV{GIT_AUTHOR_EMAIL} = $email;
-            my $status = system( 'pristine-tar', 'commit', $tarball, "upstream/".$self->version );
-            %ENV = %backup_ENV;
-            warn "error running pristine-tar: $!\n" if $status < 0;
+            system( 'pristine-tar', 'commit', $tarball, "upstream/".$self->version ) >= 0
+                or warn "error running pristine-tar: $!\n";
         }
         else {
             die "No tarball found to handle with pristine-tar. Bailing out."
@@ -917,7 +863,7 @@ You can also look for information at:
 
 =over 4
 
-=item * Debian Bug Tracking System
+=item * Debian Bugtracking System
 
 L<https://bugs.debian.org/dh-make-perl>
 
@@ -939,7 +885,7 @@ L<https://bugs.debian.org/dh-make-perl>
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2020 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2014 Gregor Herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007,2008,2009,2010,2011,2012,2015 Damyan Ivanov <dmn@debian.org>
 
