@@ -12,7 +12,7 @@ This module implements the I<refresh> command of L<dh-make-perl(1)>.
 
 use strict; use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 use base 'DhMakePerl::Command::Packaging';
 use Debian::Control::FromCPAN;
@@ -64,8 +64,9 @@ sub execute {
     print "Found examples: @{ $self->examples }\n"
         if @{ $self->examples } and $self->cfg->verbose;
 
-    if ( $self->cfg->only->{rules} ) {
+    if ( $self->cfg->only->{only} ) {
         $self->create_rules;
+        $self->create_compat( $self->debian_file('compat') );
     }
 
     if ( $self->cfg->only->{examples} ) {
@@ -96,15 +97,12 @@ sub execute {
             catfile( $self->debian_dir, 'source', 'format' ) );
 
         $self->discover_dependencies;
+
         $self->discover_utility_deps($control);
-        $self->control->prune_perl_deps;
         $control->prune_perl_deps();
 
         $self->backup_file( $self->debian_file('control') );
-        $self->backup_file( $self->debian_file('compat') );
-
         $control->write( $self->debian_file('control') );
-        $self->cme_fix_dpkg_control( $self->main_dir );
     }
 
     print "--- Done\n" if $self->cfg->verbose;
@@ -234,7 +232,7 @@ sub drop_quilt {
 
 =item Copyright (C) 2008, 2009, 2010 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2010, 2014, 2019 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2010, 2014 gregor herrmann <gregoa@debian.org>
 
 =back
 
