@@ -3,7 +3,7 @@ package DhMakePerl::Config;
 use strict;
 use warnings;
 
-our $VERSION = '0.121';
+our $VERSION = '0.91';
 
 =head1 NAME
 
@@ -19,28 +19,23 @@ my @OPTIONS = (
     'basepkgs=s',
     'bdepends=s',      'bdependsi=s',
     'build-source!',
-    'build!',          'build-script=s',
-    'closes=i',
-    'cache-dir=s',
-    'config-dir=s',    'config-file=s',
-    'core-ok',
+    'build!',          'closes=i',
+    'config-file=s',   'core-ok',
     'cpan-mirror=s',   'cpan=s',
     'cpanplus=s',      'data-dir=s',
     'dbflags=s',       'depends=s',
     'desc=s',          'dh=i',
     'dist=s',          'email|e=s',
-    'exclude|i:s{,}',  'force-depends=s',
-    'guess-nocheck!',
+    'exclude|i:s{,}',
     'home-dir=s',      'install!',
     'install-deps',     'install-build-deps',
-    'install-with=s',
     'intrusive!',
     'network!',
     'nometa',          'notest',
     'only|o=s@',
     'packagename|p=s', 'pkg-perl!',
     'recursive!',
-    'requiredeps',     'revision=s',
+    'requiredeps',
     'source-format=s', 'vcs=s',
     'verbose!',        'version=s',
 );
@@ -69,23 +64,15 @@ use Getopt::Long;
 use Tie::IxHash ();
 use YAML        ();
 
-use constant XDG_HOME => {
-    CONFIG => $ENV{XDG_CONFIG_HOME} || "$ENV{HOME}/.config",
-    CACHE  => $ENV{XDG_CACHE_HOME} || "$ENV{HOME}/.cache",
-};
-
 use constant DEFAULTS => {
     backups       => 1,
     data_dir      => '/usr/share/dh-make-perl',
     dbflags       => ( $> == 0 ? "" : "-rfakeroot" ),
-    dh            => 13,
+    dh            => 9,
     dist          => '',
     email         => '',
-    exclude       => Dpkg::Source::Package->get_default_diff_ignore_regex(),
+    exclude       => qr/$Dpkg::Source::Package::diff_ignore_default_regexp/,
     home_dir      => "$ENV{HOME}/.dh-make-perl",
-    install_with  => 'apt',
-    config_dir    => XDG_HOME->{CONFIG} . "/dh-make-perl",
-    cache_dir     => XDG_HOME->{CACHE} . "/dh-make-perl",
     network       => 1,
     only          => {
         map (
@@ -166,34 +153,11 @@ sub parse_command_line_options {
     $opts{exclude} = $self->DEFAULTS->{'exclude'} if ! $opts{exclude}; # arguments not specified
                                                                        # back to defaults
 
-    if ($opts{version} and $opts{version} =~ /-/) {
-        warn "W: Specified value for --version contains a dash ('-').\n";
-        warn "W: This was required before if one wants to control the revision\n";
-        warn "W: of the resulting package. This is no longer the case and the\n";
-        warn "W: value is used only for the upstream part of the version.\n";
-        warn "W: Use --revision if you need to control the revision.\n";
-    }
-
     # handle comma-separated multiple values in --only
     $opts{only}
         = { map ( ( $_ => 1 ), split( /,/, join( ',', @{ $opts{only} } ) ) ) }
         if $opts{only};
 
-    # Handle backwards compatibility. Explicit --cache-dir or --config-dir
-    # have preference over --home-dir. If none is specified and the legacy
-    # home directory exists use that, otherwise use the XDG directories.
-    my $home_dir = $opts{'home-dir'};
-    if ( -d $self->DEFAULTS->{home_dir} ) {
-        $home_dir //= $self->DEFAULTS->{home_dir};
-    }
-    if ( defined $home_dir ) {
-        $opts{'config-dir'} //= $home_dir;
-        $opts{'cache-dir'} //= $home_dir;
-    }
-
-    die "--depends and --force-depends can't be used at the same time\n"
-        if $opts{depends} and $opts{'force-depends'};
-
     while ( my ( $k, $v ) = each %opts ) {
         my $field = $k;
         $field =~ s/-/_/g;
@@ -201,9 +165,6 @@ sub parse_command_line_options {
         $self->_explicitly_set->{$k} = 1;
     }
 
-    die "Unknown value for --install-with\n"
-        unless $self->install_with =~ /^(apt(-get|itude)?|dpkg)$/;
-
     # see what are we told to do
     %opts = ();
     Getopt::Long::Configure('no_pass_through');
@@ -275,7 +236,7 @@ sub parse_command_line_options {
 =item parse_config_file()
 
 Parse configuration file. I<config_file> member is used for location the file,
-if not set, F<dh-make-perl.conf> file in I<config_dir> is used.
+if not set, F<dh-make-perl.conf> file in I<home_dir> is used.
 
 =cut
 
@@ -283,7 +244,7 @@ sub parse_config_file {
     my $self = shift;
 
     my $fn = $self->config_file
-        || catfile( $self->config_dir, 'dh-make-perl.conf' );
+        || catfile( $self->home_dir, 'dh-make-perl.conf' );
 
     if ( -e $fn ) {
         local $@;
@@ -369,7 +330,7 @@ sub check_obsolete_entries {
 
 =item Copyright (C) 2008-2010 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2009-2019 Gregor Herrmann <gregoa@debian.org>
+=item Copyright (C) 2009-2010 Gregor Herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2009 Ryan Niebur <RyanRyan52@gmail.com>
 
